<?php
namespace ahura\app;

use ahura\app\mw_assets;
class woocommerce
{
    static function is_active()
    {
        return class_exists('WooCommerce');
    }
    static function is_woocommerce()
    {
        return self::is_active() && is_woocommerce();
    }

    public static function is_account_page()
    {
        return self::is_active() && function_exists('is_account_page') && is_account_page();
    }

    static function is_product()
    {
        return self::is_active() && is_product();
    }

    static function is_shop()
    {
        return self::is_active() && is_shop();
    }
    static function is_woocommerce_page()
    {
        return self::is_active() && (is_woocommerce() || is_cart() || is_checkout() || is_account_page());
    }
    
    public static function is_archive(){
        return woocommerce::is_woocommerce() && (is_shop() || is_product_category() || is_product_tag() || is_product_taxonomy());
    }
    
    static function before_shop_loop_item()
    {
        $product_style = mw_options::get_product_item_style();
        if(empty($product_style) || $product_style == 1){
            $terms = wp_get_post_terms(get_the_ID(), 'product_cat', ['fields' => 'names', 'number' => 5]);
            $term_data = '<span class="mw_term_data">';
            foreach ($terms as $term_name) {
                $term_data .= '<span class="mw_term_item">'.$term_name.'</span>';
            }
            $term_data .= '</span>';
            echo '<span class="mw_overly"></span>';
            echo $term_data;
        }
    }
    static function show_product_stock_status()
    {
        global $product;
        echo get_theme_mod('ahura_shop_show_product_stock_status') ? wc_get_stock_html( $product ) : '';
    }
    static function loop_shop_columns()
    {
        return 3;
    }

    /**
     * Handle: mw_woocommerce
     *
     * @return void
     */
    public static function enqueue_woocommerce_js(){
        $version = \ahura\app\mw_tools::get_theme_version();
        $woocommerce_js = get_template_directory_uri() . '/js/woocommerce.js';
        wp_enqueue_script('mw_woocommerce', $woocommerce_js, ['jquery'], $version, true);
        wp_localize_script('mw_woocommerce', 'mw_woo_data', mw_assets::get_localize_data());
    }

    static function load_assets()
    {
        $version = \ahura\app\mw_tools::get_theme_version();

        if(self::is_active()){
            // woocommerce.css
            wp_enqueue_style('mw_woocommerce', get_template_directory_uri() . '/css/woocommerce.css', null, $version);

            if(!is_rtl()){
                wp_enqueue_style('mw_woocommerce_ltr', get_template_directory_uri() . '/css/woocommerce_ltr.css', null, $version);
            }

            mw_assets::enqueue_script('woocommerce_variations', mw_assets::get_js('woocommerce_variations'));

            self::enqueue_woocommerce_js();

            if(self::is_woocommerce_page() || is_shop())
            {
                if(is_cart() || is_checkout())
                {
                    $btn_style = '.woocommerce .button.alt{ background-color: var(--mw_primary_color); color: #222; }';
                    wp_add_inline_style('style', $btn_style);
                }
            }
        }
    }
    static function woocommerce_cart_item_thumbnail($thumbnail, $cart_item, $cart_item_key){
        $cart_image_id = $cart_item['data']->get_image_id();
        $image = wp_get_attachment_image($cart_image_id, 'thumbnail');
        return $image;
    }
    static function related_products_args($args)
    {
        $args['posts_per_page'] = 3;
        $args['columns'] = 3;
        return $args;
    }
    static function change_shop_item_count_per_page( $cols ) {
        // $cols contains the current number of products per page based on the value stored on Options –> Reading
        // Return the number of products you wanna show per page.
        $cols = get_theme_mod('ahura_shop_per_page', 9);
        return $cols;
    }
    static function change_sale_text($text){
        $text = get_theme_mod('woocommerce_sale_text') ? get_theme_mod('woocommerce_sale_text') : __('Sale!','woocommerce');
        $product_discount_percent = get_theme_mod('ahura_shop_show_product_onsale_percent') ? sprintf('%%%d', ahura_get_product_discount_percent()) . ' ' : '';
        $text = '<span class="onsale">' . sprintf('%s %s', $product_discount_percent, $text) . '</span>';
        return $text;
    }

    public static function add_to_cart_button_with_quantity($params = []){
        global $product;
        if(isset($params['product']) && is_object($params['product'])){
            $product = $params['product'];
        }
        if(is_object($product)){
            echo '<form action="' . esc_url($product->add_to_cart_url()) . '" class="d-flex align-center cart product-quantity-form crousel_addtobtn '. (isset($params['class']) ? $params['class'] : '') .'" method="post" enctype="multipart/form-data">';

            if(!isset($params['with_qty']) || isset($params['with_qty']) && $params['with_qty'] === true){
                echo woocommerce_quantity_input(['min_value' => 1, 'max_value' => (!$product->backorders_allowed() ? $product->get_stock_quantity() : '')]);
            }

            $btn_text = __('Add to Cart', 'ahura');
            if(isset($params['button_text'])){
                $btn_text = $params['button_text'];
            }

            $btn_icon = '';
            if(isset($params['has_button_icon']) && $params['has_button_icon'] === true){
                $btn_icon = '<i class="fa fa-shopping-cart"></i>';
                if(isset($params['button_icon'])){
                    $btn_icon = $params['button_icon'];
                }
            }

            echo '<button type="submit" class="button alt">'. $btn_icon . ' ' . $btn_text .'</button>';
            echo '</form>';
        }
    }

    public static function added_inquiry_text_for_without_products($price, $product){
        if('' === $product->get_price()) {
            $text = \ahura\app\mw_options::get_mod_text_call_for_price_inquery();
            $text = !empty($text) ? $text : esc_html__('Call for price inquiry', 'ahura');
            $btn_text = \ahura\app\mw_options::get_mod_call_for_price_inquery_button_text();
            $btn_url = \ahura\app\mw_options::get_mod_call_for_price_inquery_button_url();
            $output = "<div class='price_on_inquiry'><span>{$text}</span>";
            if(!empty($btn_url) && is_single()){
                $output .= "<a href='{$btn_url}' class='button'>{$btn_text}</a>";
            }
            $output .= "</div>";
            return $output;
        }
    
        return $price;
    }

    public static function change_single_product_add_to_cart_button_text(){
        $status = \ahura\app\mw_options::get_mod_change_add_to_cart_button_text_status();
        $text = \ahura\app\mw_options::get_mod_add_to_cart_button_text();
        if($status && !empty($text)){
            return $text;
        }
        return __('Add to Cart', 'ahura'); 
    }

    public static function before_shop_add_to_cart_button($product){
        $is_pages = is_woocommerce() && !is_single();
        if (!$is_pages || \ahura\app\mw_options::get_product_item_style() != 2)
            return false;

        self::render_product_colors($product);
    }

    public static function render_product_colors($product, $limit = false)
    {
        $colors = get_the_terms($product->get_id(), 'pa_color');
        if (!empty($colors) && !is_wp_error($colors)){
            ?>
            <div class="product-colors">
                <?php if ($limit && count($colors) > $limit): ?>
                    <span class="has-more">+</span>
                <?php endif; ?>
                <?php $i = 0;
                foreach ($colors as $color):
                    $i++;
                    $term_id = is_object($color) ? $color->term_id : (isset($color['term_id']) ? $color['term_id'] : null);
                    if (!$term_id) continue;

                    $data = get_term_meta($term_id);
                    $color_code = isset($data['_product_attribute_color'][0]) && !empty($data['_product_attribute_color'][0]) ? $data['_product_attribute_color'][0] : null;

                    if (!$color_code) continue;
                    ?>
                    <span class="product-color-item" title="<?php echo isset($color->name) ? $color->name : '' ?>" style="background-color:<?php echo $color_code ?>"></span>
                <?php
                    if ($limit && $i >= $limit)
                        break;
                endforeach;
                ?>
            </div>
        <?php }
    }

    public static function handle_add_quick_view_button_before_shop_add_to_cart($product)
    {
        ?>
        <a href="#" class="product-preview-btn" data-id="<?php echo $product->get_id() ?>" title="<?php _e('Quick View', 'ahura') ?>">
            <?php echo apply_filters('ahura_product_quick_view_button_text', '<i class="fas fa-eye"></i>') ?>
        </a>
    <?php
    }

    public static function handle_move_out_of_stock_products_to_end($posts_clauses)
    {
        if (woocommerce::is_woocommerce() && (is_shop() || is_product_category() || is_product_tag() || is_product_taxonomy())) {
            global $wpdb;
            $posts_clauses['join'] .= " INNER JOIN $wpdb->postmeta istockstatus ON ($wpdb->posts.ID = istockstatus.post_id) ";
            $posts_clauses['orderby'] = " istockstatus.meta_value ASC, " . $posts_clauses['orderby'];
            $posts_clauses['where'] = " AND istockstatus.meta_key = '_stock_status' AND istockstatus.meta_value <> '' " . $posts_clauses['where'];
        }
        return $posts_clauses;
    }

    public static function handle_load_woocommerce_single_template($template, $product)
    {
        $template_dir = get_template_directory() . '/woocommerce/single-product/';

        $templates = [
                'digikala' => 'digi',
                'digitalmarketplace' => 'digital',
        ];

        $templates = apply_filters('ah_get_woocommerce_single_templates', $templates);

        include $template_dir . (isset($templates[$template]) ? $templates[$template] : 'default') . '-single-product.php';
    }

    public static function handle_load_woocommerce_single_review_template($product)
    {
        $template_dir = get_template_directory() . '/woocommerce/templates/review/';
        $mode = mw_options::get_mod_product_review_template_mode();

        include $template_dir . 'product-review-' . (!empty($mode) ? $mode : 'default') . '.php';
    }

    public static function handle_load_woocommerce_single_review_item_template($args)
    {
        $template_dir = get_template_directory() . '/woocommerce/templates/review/';
        $mode = mw_options::get_mod_product_review_template_mode();

        if (is_array($args) && !empty($args)){
            extract($args);
        }

        include $template_dir . 'review-item-' . (!empty($mode) ? $mode : 'default') . '.php';
    }

    public static function get_shop_views()
    {
        $shop_views = [
            'default' => ahura_get_full_path('img.icons.svg', 'grid-cols-3.svg'),
            'list' => ahura_get_full_path('img.icons.svg', 'grid-full.svg'),
        ];
        return apply_filters('ah_get_shop_views', $shop_views);
    }

    public static function get_current_shop_view()
    {
        $view = $_GET['shop_view'] ?? null;
        return mw_options::get_mod_shop_grid_status() && in_array($view, array_keys(self::get_shop_views())) ? sanitize_text_field($view) : 'default';
    }

    public static function handle_save_review_meta($comment_id)
    {
        if(mw_options::get_mod_product_review_strength_weak_points_status()){
            if (isset($_POST['plus-rate'])){
                add_comment_meta($comment_id, 'comment_plus_rate', ahura_sanitize_recursive($_POST['plus-rate']));
            }
            if (isset($_POST['negative-rate'])){
                add_comment_meta($comment_id, 'comment_negative_rate', ahura_sanitize_recursive($_POST['negative-rate']));
            }
        }
    }

    public static function handle_append_data_after_review_text($comment)
    {
        $plus_rates = get_comment_meta($comment->comment_ID, 'comment_plus_rate', true);
        $negative_rates = get_comment_meta($comment->comment_ID, 'comment_negative_rate', true);

        $comment_likes = (int) get_comment_meta($comment->comment_ID, 'comment_likes', true) ?? 0;
        $comment_dislikes = (int) get_comment_meta($comment->comment_ID, 'comment_dislikes', true) ?? 0;
        ?>
        <?php if (mw_options::get_mod_product_review_strength_weak_points_status() && (!empty($plus_rates) || !empty($negative_rates))): ?>
        <div class="comment-rate-list">
            <div class="row">
                <?php if ($plus_rates): ?>
                <div class="col-12 col-md-6">
                    <div class="ah-box-title plus-rate-title"><?php _e('Strength Points', 'ahura') ?></div>
                    <div class="comment-plus-rates">
                        <?php if (!empty($plus_rates) && is_array($plus_rates)): ?>
                            <?php
                            foreach($plus_rates as $text):
                                if (empty($text)) continue;
                                ?>
                                <div class="comment-rate-item"><?php echo $text ?></div>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </div>
                </div>
                <?php endif; ?>
                <?php if ($negative_rates): ?>
                <div class="col-12 col-md-6">
                    <div class="ah-box-title negative-rate-title"><?php _e('Weak Points', 'ahura') ?></div>
                    <div class="comment-negative-rates">
                        <?php if (!empty($negative_rates) && is_array($negative_rates)): ?>
                            <?php
                            foreach($negative_rates as $text):
                                if (empty($text)) continue;
                                ?>
                                <div class="comment-rate-item"><?php echo $text ?></div>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </div>
                </div>
                <?php endif; ?>
            </div>
        </div>
        <?php endif; ?>
        <?php if(mw_options::get_mod_product_review_like_status()):?>
        <div class="comment-actions">
            <div class="title"><?php _e('Was this comment helpful to you?','ahura'); ?></div>
            <div class="comment-like">
                <button class="comment-like-btn" data-action="like" data-id="<?php comment_ID(); ?>">
                    <?php _e('Yes', 'ahura'); ?>
                    <span class="count"><?php echo $comment_likes; ?></span>
                </button>
            </div>
            <div class="comment-like">
                <button class="comment-like-btn" data-action="dislike" data-id="<?php comment_ID(); ?>">
                    <?php _e('No', 'ahura'); ?>
                    <span class="count"><?php echo $comment_dislikes; ?></span>
                </button>
            </div>
        </div>
        <?php endif; ?>
    <?php
    }

    public static function ahura_remove_price_on_outofstock_products($price, $product) {
        if (!$product->is_in_stock()) return false;
        return $price;
    }

    public static function remove_product_sku_on_single_page($enabled) {
        if (!is_admin() && is_product()) {
            global $product;
            if (is_object($product) && empty($product->get_sku()))
                return false;
        }

        return $enabled;
    }

    public static function handle_disable_zoom_product_gallery()
    {
        remove_theme_support('wc-product-gallery-zoom');
    }
}
